#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-common
version:              0.8.2.1
visibility:           public
id:                   http-common-0.8.2.1-CF1ywhYu6jA68uB320E80W
key:                  http-common-0.8.2.1-CF1ywhYu6jA68uB320E80W
license:              BSD-3-Clause
copyright:            © 2012-2020 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/istathar/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  c2f430f29f1f9b4a61cba30e90ba82ca
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-common-0.8.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-common-0.8.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-common-0.8.2.1
hs-libraries:         HShttp-common-0.8.2.1-CF1ywhYu6jA68uB320E80W
depends:
    base-4.14.2.0 base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-6tEs2ust6UoJNkdDoolIXx directory-1.3.6.0
    mtl-2.2.2 network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

